@@ -33,9 +33,10 @@
 #  define KDE_DEPRECATED_NO_EXPORT LIBKDEGAMES_NO_EXPORT KDE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKDEGAMES_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKDEGAMES_NO_DEPRECATED
+#    define LIBKDEGAMES_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
