@@ -33,9 +33,10 @@
 #  define KDE_DEPRECATED_NO_EXPORT LIBKDEGAMESPRIVATE_NO_EXPORT KDE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKDEGAMESPRIVATE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKDEGAMESPRIVATE_NO_DEPRECATED
+#    define LIBKDEGAMESPRIVATE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
